@@ -20,11 +20,4 @@ def rotate(begin = 'Downloading', sleep_value = 0.1):
     for i in list:
         sleep(sleep_value)
         ting = i
-        print(f'\r{begin} {ting}', end='\r')
-
-import math
-numbers = [x * 5 for x in range(100, 2000)]
-list = []
-for i, a in enumerate(numbers):
-    list.append(math.factorial(i))
-    bar(i + 1, len(numbers))
\ No newline at end of file
+        print(f'\r{begin} {ting}', end='\r')
\ No newline at end of file
